package com.caimei365.tools.mapper;

import com.caimei365.tools.model.po.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/11/2
 */
@Mapper
public interface CmBehaviorRecordMapper {

    /**
     * 用户行为记录
     * @param cmBehaviorRecordPo
     * @return
     */
    void insertRecord(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 当天访问网站IP、userId
     * @param cmBehaviorRecordPo
     */
    List<CmBehaviorRecordPo> toDateRecode(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 当天访问网站IP、userId的详细数据
     * @param cmBehaviorRecordPo
     */
    List<CmBehaviorRecordPo> toDateIPTimeRecode(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 计算真是访问时长
     * @param cmBehaviorRecordPo
     */
    void updateDuration(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 查询所有老数据
     * @return
     */
    List<CmUserPo> findList(@Param("startId") Integer startId, @Param("endId") Integer endId);

    /**
     * sku信息
     * @return
     */
    List<CmSkuPo> skuList();

    /**
     * 修改sku信息
     * @param skuPo
     */
    void updateSku(CmSkuPo skuPo);
    /**
     * 修改老数据ip所在地
     * @param userPo
     */
    void updateOldData(CmUserPo userPo);

    CmVipCouponPo selSvipCoupon(@Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 将本季度优惠券开放
     * @param cmVipCouponPo
     */
    void updateSvipCoupon(CmVipCouponPo cmVipCouponPo);

    /**
     * 生成下一季度优惠券
     * @param cmVipCouponPo
     */
    void insertVipCouponMonth(CmVipCouponPo cmVipCouponPo);

    List<CmCouponPo> selCoupon();

    void updateCoupon(CmCouponPo cmCouponPo);

    void insertCoupon(CmCouponPo cmCouponPo);

    List<CmCouponAssociatePo> selCouponPro(@Param("couponId") Integer couponId);

    /**
     * 插入新优惠券商品
     * @param associate
     */
    void insertCouponAssociate(CmCouponAssociatePo associate);

    Integer selSvipCouponById();

    /**
     * vip优惠券月份关系
     * @param cmVipCouponRelation
     */
    void insertRelation(CmVipCouponRelation cmVipCouponRelation);

    List<CmBehaviorRecordPo> countNum(@Param("accessDate") String accessDate);

    CmBehaviorRecordPo userIdAcc(@Param("IP") String IP, @Param("accessDate") String accessDate);

    List<CmBehaviorRecordPo> selBehaviorList(@Param("IP") String IP, @Param("accessDate") String accessDate);

    void updateBehavior(CmBehaviorRecordPo cmBehaviorRecordPo);

    List<CmBehaviorRecordPo> selYesterdayList(@Param("accessDate") String accessDate);

    /**
     * 插入昨日数据
     * @param cmBehaviorRecordPo
     */
    void insertYesterdayList(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 查询今日所有用户行为数据
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> selTodayData(@Param("accessDate") String accessDate);

    /**
     * 关联供应商数据
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> selDataList(@Param("accessDate") String accessDate);

    /**
     * 将今日数据存储到今日数据表
     * @param cmBehaviorRecordPo 参数
     */
    void inBehaviorToday(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 清除今日用户数据数据
     */
    void delTodayData();

    /**
     * 所有供应商关联标签
     * @return
     */
    List<String> shopKeyword();

    /**
     * 查询供应商id
     * @param strList 页面标签
     * @return 返回
     */
    List<Integer> shopIds(@Param("strList") List<String> strList);

    /**
     * 获取是否关联供应商
     * @param ShopId
     * @return
     */
    Integer selShopId(@Param("shopId") Integer ShopId);
    /**
     * 添加惯量供应商
     * @param recordId 用户行为记录id
     * @param shopId 供应商id
     */
    void insertShopId(@Param("recordId") Integer recordId, @Param("shopId") Integer shopId);

    /**
     * 个人机构注册ip
     * @return
     */
    List<CmBehaviorRecordPo> selRegisterIP(Integer startId, Integer endId);

    /**
     * 省份
     * @return
     */
    Integer selProvince(@Param("regionPro") String regionPro);

    /**
     * 市
     * @return
     */
    AddressPo selCity(@Param("regionCity") String regionCity);

    /**
     * 更新机构地址数据
     */
    void upClubAddress(@Param("clubId") String clubId, @Param("provinceId") Integer provinceId, @Param("cityId") Integer cityId);

    /**
     * 需要统计的供应商Id
     * @return
     */
    List<Integer> getShopId();

    /**
     * 需要统计的供应商商品Id
     * @return
     */
    List<Integer> getProductId(@Param("shopId") Integer shopId);

    /**
     * 需要统计的供应商文章Id
     * @param shopId
     * @return
     */
    List<Integer> getShopInfoId(@Param("shopId") Integer shopId);

    /**
     * 需要统计的供应商搜索词Id
     * @param shopId
     * @return
     */
    List<SearchFrequencyVo> getShopKeywordId(@Param("shopId") Integer shopId);

    /**
     * 检索统计信息
     * @param accessDate
     * @param pageType
     * @param pagePath
     * @return
     */
    CmBehaviorRecordPo getBehaviorList(@Param("accessDate") String accessDate , @Param("pageType") Integer pageType, @Param("pagePath") String pagePath);

    /**
     * 添加供应商主页统计数据
     * @param cmPageShopPo
     */
    void insertPageShop(CmPageShopPo cmPageShopPo);

    /**
     * 添加供应商商品统计数据
     * @param cmPageShopProductPo
     */
    void insertPageProduct(CmPageShopProductPo cmPageShopProductPo);

    /**
     * 添加供应商文章统计数据
     * @param cmPageShopInfoPo
     */
    void insertPageInfo(CmPageShopInfoPo cmPageShopInfoPo);

    /**
     * 添加供应商搜索词统计数据
     * @param cmPageShopKeywordPo
     */
    void insertPageKeyword(CmPageShopKeywordPo cmPageShopKeywordPo);
}

